
/**
 * @overview Defines the SessionJanitor job which is responsible for removing
 * expired sessions from the datastore.
 *
 * @module stout-session/job/SessionJanitor
 */

(function() {
  var DEFAULT_SCHEDULE, Job,
    slice = [].slice;

  Job = require('stout-server/job/Job');

  DEFAULT_SCHEDULE = '*';

  module.exports = Job.extend('SessionJanitor', {
    constructor: function(schedule) {
      if (schedule == null) {
        schedule = DEFAULT_SCHEDULE;
      }
      Job.prototype.constructor.call(this, schedule);
    },

    /**
     * The task function directs the session provider to delete expired sessions
     *
     * @method run
     * @memberof stout-session/job/SessionJanitor
     */
    run: function() {
      return this.__provider.deleteExpiredSessions(20);
    },

    /**
     * SessionJanitor boot routine which simply grabs the session provider.
     *
     * @method $boot
     * @memberof stout-session/job/SessionJanitor
     */
    $boot: function(app, config, components, log) {
      var ref;
      (ref = Job.$boot).call.apply(ref, [this].concat(slice.call(arguments)));
      this.prototype.__provider = app.providers.get('SessionProvider');
      return DEFAULT_SCHEDULE = config.get('session.janitor.schedule', '*');
    }
  });

}).call(this);

//# sourceMappingURL=SessionJanitor.js.map
