
/**
 * @overview Defines the Session provider.
 *
 * @module stout-session/provider/SessionProvider
 */

(function() {
  var ModelProvider, SessionProvider, map;

  map = require('lodash/map');

  ModelProvider = require('stout-orm/provider/ModelProvider');


  /**
   * The SessionProvider class provides the interface for CRUD operations on
   * sessions.
   *
   * @exports stout-session/provider/SessionProvider
   * @extends stout-orm/provider/ModelProvider
   * @constructor
   */

  module.exports = SessionProvider = ModelProvider.extend('SessionProvider', {
    datastore: 'SessionDatastore',
    model: 'Session',

    /**
     * Retrieves up to `n` expired sessions.
     *
     * @param {number} [n] - The maximum number of expired sessions to retrieve.
     *
     * @returns {stout-core/promise/Promise}
     *
     * @method getExpiredSessions
     * @memberof stout-session/provider/SessionProvider#
     */
    getExpiredSessions: function(n) {
      return this.datastore.filter('expires', '<=', Date.now()).limit(n).then((function(_this) {
        return function(results) {
          return map(results, function(data) {
            return _this._instantiateModel(data);
          });
        };
      })(this));
    },

    /**
     * Deletes up to `n` expired sessions.
     *
     * @param {number} [n] - The maximum number of expired sessions to delete.
     *
     * @returns {stout-core/promise/Promise}
     *
     * @method deleteExpiredSessions
     * @memberof stout-session/provider/SessionProvider#
     */
    deleteExpiredSessions: function(n) {
      return this.datastore.filter('expires', '<=', Date.now()).limit(n).select('key')["delete"]();
    }
  });

}).call(this);

//# sourceMappingURL=SessionProvider.js.map
