###*
# @overview Defines the SessionJanitor job which is responsible for removing
# expired sessions from the datastore.
#
# @module stout-session/job/SessionJanitor
###
Job = require 'stout-server/job/Job'



DEFAULT_SCHEDULE = '*'



module.exports = Job.extend 'SessionJanitor',

  constructor: (schedule = DEFAULT_SCHEDULE) ->
    Job.prototype.constructor.call @, schedule
    return


  ###*
  # The task function directs the session provider to delete expired sessions
  #
  # @method run
  # @memberof stout-session/job/SessionJanitor
  ###
  run: ->
    @__provider.deleteExpiredSessions(20)


  ###*
  # SessionJanitor boot routine which simply grabs the session provider.
  #
  # @method $boot
  # @memberof stout-session/job/SessionJanitor
  ###
  $boot: (app, config, components, log) ->
    Job.$boot.call @, arguments...
    # Register the job with the supervisor, then update the schedule based on
    # the config.
    @::__provider = app.providers.get 'SessionProvider'
    DEFAULT_SCHEDULE = config.get('session.janitor.schedule', '*')
