assert    = require('chai').assert
Session   = require '../../../model/Session'

sinon   = require 'sinon'



describe 'model/Session', ->
  session = null

  beforeEach ->
    Session.hasOne = []
    session = new Session

  for prop in ['data', 'expired', 'expires']
    ((prop) ->
      it "has a ##{prop} property", ->
        assert.property session, prop
    )(prop)

  for method in ['get', 'has', 'set', 'touch']
    ((method) ->
      it "has a ##{method}() method", ->
        assert.isFunction session[method]
    )(method)



  describe 'session expiration', ->

    it 'new sessions are not expired', ->
      assert.isFalse session.expired

    it '#expires is a Date object', ->
      assert.instanceOf session.expires, Date

    it 'uses Session.maxAge to set the expiration time', ->
      actualExp = session.expires.getTime()
      expectedExp = Date.now() + Session.maxAge * 1000
      assert.approximately actualExp, expectedExp, 10 * 1000

    specify '#touch() refreshes and saves the session', (done) ->
      session.save = sinon.spy()
      pt = session.expires.getTime()
      setTimeout ->
        session.touch()
        assert.isAbove session.expires.getTime(), pt
        assert.isTrue session.save.calledOnce
        done()
      , 10

    specify '#touch() returns the value returned by #save()', ->
      ret = {}
      session.save = -> ret
      assert.equal session.touch(), ret



  describe 'session data', ->

    specify '#data is an object', ->
      assert.isObject session.data

    specify '#data is serialized', ->
      obj = {a: 1, b: {c: 3}}
      session.data = obj
      assert.deepEqual session.toObject().data, obj

    specify 'session data can be get/set by path using #set() and #get()', ->
      session.set 'a.b.c.d', 123
      assert.equal session.get('a.b.c.d'), 123

    specify '#has() indicates if session data exists', ->
      assert.isFalse session.has 'a.b.c.d'
      session.set 'a.b.c.d', 123
      assert.isTrue session.has 'a.b.c.d'
